=== modified file 'drizzled/catalog/instance.h'
--- drizzled/catalog/instance.h	2011-03-28 14:32:36 +0000
+++ drizzled/catalog/instance.h	2012-07-11 14:06:00 +0000
@@ -23,6 +23,8 @@
 #include <boost/thread/mutex.hpp>
 #include <boost/make_shared.hpp>
 
+#include <drizzled/identifier.h>
+#include <drizzled/identifier/catalog.h>
 #include <drizzled/message/catalog.h>
 
 namespace drizzled {
@@ -32,7 +34,8 @@
 {
   Instance() :
     _locked(false),
-    _lock_id(0)
+    _lock_id(0),
+    _identifier(str_ref(""))
   { };
 
   bool _locked;
@@ -40,6 +43,7 @@
   message::catalog::shared_ptr _message;
   mutable boost::mutex _schema_lock;
   mutable boost::mutex _system_variable_lock;
+  drizzled::identifier::Catalog _identifier;
 
 
 public:
@@ -49,12 +53,14 @@
   typedef const Instance& const_reference;
   typedef Instance& reference;
 
-  Instance(message::catalog::shared_ptr &message_arg)
+  Instance(message::catalog::shared_ptr &message_arg) :
+    _identifier(message_arg->name())
   {
     _message= message_arg;
   };
 
-  Instance(const message::catalog::shared_ptr &message_arg)
+  Instance(const message::catalog::shared_ptr &message_arg) :
+    _identifier(message_arg->name())
   {
     _message= message_arg;
   };
@@ -72,6 +78,11 @@
     return boost::make_shared<Instance>(new_message);
   }
 
+  const drizzled::identifier::Catalog &identifier() const
+  {
+    return _identifier;
+  }
+
   const std::string &getName() const
   {
     assert(_message);

=== modified file 'drizzled/cursor.cc'
--- drizzled/cursor.cc	2012-02-12 07:40:43 +0000
+++ drizzled/cursor.cc	2012-07-11 14:06:00 +0000
@@ -89,7 +89,7 @@
     when the clone Cursor object is destroyed.
   */
   new_handler->ref= mem_root->alloc(ALIGN_SIZE(ref_length)*2);
-  identifier::Table identifier(getTable()->getShare()->getSchemaName(), getTable()->getShare()->getTableName(), getTable()->getShare()->getType());
+  identifier::Table identifier(*getTable());
   return new_handler->ha_open(identifier, getTable()->getDBStat(), HA_OPEN_IGNORE_IF_LOCKED) ? NULL : new_handler;
 }
 

=== modified file 'drizzled/identifier/constants/schema.cc'
--- drizzled/identifier/constants/schema.cc	2012-04-23 02:17:12 +0000
+++ drizzled/identifier/constants/schema.cc	2012-07-11 14:06:00 +0000
@@ -20,6 +20,7 @@
 
 #include <config.h>
 #include <drizzled/identifier.h>
+#include <drizzled/catalog/local.h>
 
 namespace drizzled {
 namespace identifier {
@@ -29,8 +30,9 @@
 class Schema : public identifier::Schema
 {
 public:
+  /* FIXME: use a global identifier for catalog */
   Schema(const char* name) :
-    identifier::Schema(str_ref(name))
+    identifier::Schema(drizzled::catalog::local_identifier(), str_ref(name))
   {
   }
 

=== modified file 'drizzled/identifier/schema.cc'
--- drizzled/identifier/schema.cc	2012-07-11 12:11:04 +0000
+++ drizzled/identifier/schema.cc	2012-07-11 14:06:00 +0000
@@ -41,9 +41,10 @@
 namespace drizzled {
 namespace identifier {
 
-Schema::Schema(str_ref db_arg) :
+Schema::Schema(const drizzled::identifier::Catalog &catalog_arg,
+                 str_ref db_arg) :
   db(db_arg.data(), db_arg.size()),
-  _catalog(drizzled::catalog::local_identifier())
+  _catalog(catalog_arg)
 { 
 #if 0
   string::size_type lastPos= db.find_first_of('/', 0);

=== modified file 'drizzled/identifier/schema.h'
--- drizzled/identifier/schema.h	2012-07-11 13:10:06 +0000
+++ drizzled/identifier/schema.h	2012-07-11 14:06:00 +0000
@@ -47,7 +47,7 @@
   drizzled::identifier::Catalog _catalog;
 
 public:
-  Schema(str_ref);
+  Schema(const drizzled::identifier::Catalog &catalog_arg, str_ref);
 
   virtual std::string getSQLPath() const
 	{

=== modified file 'drizzled/identifier/table.cc'
--- drizzled/identifier/table.cc	2012-07-11 13:10:06 +0000
+++ drizzled/identifier/table.cc	2012-07-11 14:06:00 +0000
@@ -190,7 +190,8 @@
 }
 
 Table::Table(const drizzled::Table &table) :
-  identifier::Schema(str_ref(table.getShare()->getSchemaName())),
+  identifier::Schema(table.getShare()->getTableIdentifier().getCatalog(),
+                     str_ref(table.getShare()->getSchemaName())),
   type(table.getShare()->getTableType()),
   table_name(table.getShare()->getTableName())
 {
@@ -212,20 +213,22 @@
   init();
 }
 
-Table::Table(const std::string &db_arg,
+Table::Table(const drizzled::identifier::Catalog &catalog,
+             const std::string &db_arg,
              const std::string &table_name_arg,
              Type tmp_arg) :
-  Schema(db_arg),
+  Schema(catalog, db_arg),
   type(tmp_arg),
   table_name(table_name_arg)
 { 
   init();
 }
 
-Table::Table(const std::string &schema_name_arg,
+Table::Table(const drizzled::identifier::Catalog &catalog,
+             const std::string &schema_name_arg,
              const std::string &table_name_arg,
              const std::string &path_arg ) :
-  Schema(schema_name_arg),
+  Schema(catalog, schema_name_arg),
   type(message::Table::TEMPORARY),
   path(path_arg),
   table_name(table_name_arg)

=== modified file 'drizzled/identifier/table.h'
--- drizzled/identifier/table.h	2012-07-11 13:10:06 +0000
+++ drizzled/identifier/table.h	2012-07-11 14:06:00 +0000
@@ -150,16 +150,18 @@
 public:
 
   Table(const drizzled::Table &table);
-                   
+
   Table(const identifier::Schema &schema,
         const std::string &table_name_arg,
         Type tmp_arg= message::Table::STANDARD);
 
-  Table(const std::string &db_arg,
+  Table(const drizzled::identifier::Catalog &catalog,
+        const std::string &db_arg,
         const std::string &table_name_arg,
         Type tmp_arg= message::Table::STANDARD);
 
-  Table(const std::string &schema_name_arg,
+  Table(const drizzled::identifier::Catalog &catalog,
+        const std::string &schema_name_arg,
         const std::string &table_name_arg,
         const std::string &path_arg );
 

=== modified file 'drizzled/locking/global.cc'
--- drizzled/locking/global.cc	2011-06-27 15:25:23 +0000
+++ drizzled/locking/global.cc	2012-07-11 14:06:00 +0000
@@ -93,6 +93,7 @@
 #include <drizzled/util/test.h>
 #include <drizzled/open_tables_state.h>
 #include <drizzled/table/cache.h>
+#include <drizzled/catalog/instance.h>
 
 #include <set>
 #include <vector>
@@ -618,7 +619,9 @@
 
 int Session::lock_table_name(TableList *table_list)
 {
-  identifier::Table identifier(table_list->getSchemaName(), table_list->getTableName());
+  identifier::Table identifier(catalog().identifier(),
+                               table_list->getSchemaName(),
+                               table_list->getTableName());
   {
     /* Only insert the table if we haven't insert it already */
     table::CacheRange ppp= table::getCache().equal_range(identifier.getKey());

=== modified file 'drizzled/plugin/storage_engine.cc'
--- drizzled/plugin/storage_engine.cc	2012-02-12 06:45:37 +0000
+++ drizzled/plugin/storage_engine.cc	2012-07-11 14:06:00 +0000
@@ -547,7 +547,10 @@
     message::Table definition;
     if (StorageEngine::readTableFile(path, definition))
     {
-      identifier::Table identifier(definition.schema(), definition.name(), path);
+      identifier::Table identifier(identifier::Catalog(definition.catalog()),
+                                   definition.schema(),
+                                   definition.name(),
+                                   path);
       table_identifiers.push_back(identifier);
     }
   }
@@ -733,8 +736,7 @@
     break;
   case HA_ERR_NO_SUCH_TABLE:
     {
-      identifier::Table identifier(table.getShare()->getSchemaName(), table.getShare()->getTableName());
-      my_error(ER_TABLE_UNKNOWN, identifier);
+      my_error(ER_TABLE_UNKNOWN, table.getShare()->getTableIdentifier());
       return;
     }
   case HA_ERR_LOG_ROW_FOR_REPLICATION_FAILED:

=== modified file 'drizzled/plugin/table_function.h'
--- drizzled/plugin/table_function.h	2011-08-14 17:04:01 +0000
+++ drizzled/plugin/table_function.h	2012-07-11 14:06:00 +0000
@@ -29,6 +29,7 @@
 #include <drizzled/message/table.pb.h>
 #include <drizzled/charset.h>
 #include <drizzled/field.h>
+#include <drizzled/catalog/local.h>
 
 #include <string>
 #include <set>
@@ -67,9 +68,11 @@
   void init();
 
 public:
+  /* FIXME: should use a universal catalog identifier */
   TableFunction(const char *schema_arg, const char *table_arg) :
     Plugin(local_string_append(schema_arg, table_arg) , "TableFunction"),
-    identifier(schema_arg, table_arg),
+    identifier(drizzled::catalog::local_identifier(),
+               schema_arg, table_arg),
     original_table_label(table_arg)
   {
     init();

=== modified file 'drizzled/schema.cc'
--- drizzled/schema.cc	2011-08-05 12:55:59 +0000
+++ drizzled/schema.cc	2012-07-11 14:06:00 +0000
@@ -98,8 +98,9 @@
   {
     boost::mutex::scoped_lock scopedLock(session.catalog().schemaLock());
 
-    // Check to see if it exists already.  
-    identifier::Schema schema_identifier(schema_message.name());
+    // Check to see if it exists already.
+    identifier::Schema schema_identifier(session.catalog().identifier(),
+                                         schema_message.name());
     if (plugin::StorageEngine::doesSchemaExist(schema_identifier))
     {
       if (not is_if_not_exists)
@@ -157,7 +158,8 @@
   {
     boost::mutex::scoped_lock scopedLock(session.catalog().schemaLock());
 
-    identifier::Schema schema_idenifier(schema_message.name());
+    identifier::Schema schema_idenifier(session.catalog().identifier(),
+                                        schema_message.name());
     if (not plugin::StorageEngine::doesSchemaExist(schema_idenifier))
     {
       my_error(ER_SCHEMA_DOES_NOT_EXIST, schema_idenifier);

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2012-05-31 15:20:57 +0000
+++ drizzled/session.cc	2012-07-11 14:06:00 +0000
@@ -666,7 +666,7 @@
   }
 
   /* Change database if necessary */
-  if (not in_db.empty() && schema::change(*this, identifier::Schema(in_db)))
+  if (not in_db.empty() && schema::change(*this, identifier::Schema(catalog().identifier(), in_db)))
     return false; // change() has pushed the error message
   my_ok();
 
@@ -1640,7 +1640,7 @@
   plugin::StorageEngine& table_type= *table->getShare()->db_type();
   table->free_io_cache();
   table->delete_table();
-  rm_temporary_table(table_type, identifier::Table(table->getShare()->getSchemaName(), table->getShare()->getTableName(), table->getShare()->getPath()));
+  rm_temporary_table(table_type, identifier::Table(table->getShare()->getTableIdentifier().getCatalog(), table->getShare()->getSchemaName(), table->getShare()->getTableName(), table->getShare()->getPath()));
   boost::checked_delete(table->getMutableShare());
   boost::checked_delete(table);
 }

=== modified file 'drizzled/show.cc'
--- drizzled/show.cc	2012-03-14 19:16:59 +0000
+++ drizzled/show.cc	2012-07-11 14:06:00 +0000
@@ -34,6 +34,7 @@
 #include <drizzled/statement/show_warnings.h>
 #include <drizzled/sql_lex.h>
 #include <drizzled/table_ident.h>
+#include <drizzled/catalog/instance.h>
 
 #include <sys/stat.h>
 
@@ -116,7 +117,8 @@
   util::string::ptr schema(session->schema());
   if (ident)
   {
-    identifier::Schema identifier= str_ref(ident);
+    identifier::Schema identifier(session->catalog().identifier(),
+                                  str_ref(ident));
     column_name.append(ident);
     session->lex().select_lex.db= ident;
     if (not plugin::StorageEngine::doesSchemaExist(identifier))
@@ -182,7 +184,8 @@
   {
     session->lex().select_lex.db= ident;
 
-    identifier::Schema identifier= str_ref(ident);
+    identifier::Schema identifier(session->catalog().identifier(),
+                                  str_ref(ident));
     if (not plugin::StorageEngine::doesSchemaExist(identifier))
     {
       my_error(ER_BAD_DB_ERROR, identifier);
@@ -245,7 +248,9 @@
   }
 
   {
-    drizzled::identifier::Table identifier(select->getShowSchema(), table_ident->table.data());
+    drizzled::identifier::Table identifier(session->catalog().identifier(),
+                                           select->getShowSchema(),
+                                           table_ident->table.data());
     if (not plugin::StorageEngine::doesTableExist(*session, identifier))
     {
       my_error(ER_TABLE_UNKNOWN, identifier);
@@ -308,7 +313,9 @@
   }
 
   {
-    drizzled::identifier::Table identifier(select->getShowSchema(), table_ident->table.data());
+    drizzled::identifier::Table identifier(session->catalog().identifier(),
+                                           select->getShowSchema(),
+                                           table_ident->table.data());
     if (not plugin::StorageEngine::doesTableExist(*session, identifier))
     {
       my_error(ER_TABLE_UNKNOWN, identifier);
@@ -483,7 +490,9 @@
   }
 
   {
-    drizzled::identifier::Table identifier(select->getShowSchema(), ident->table.data());
+    drizzled::identifier::Table identifier(session->catalog().identifier(),
+                                           select->getShowSchema(),
+                                           ident->table.data());
     if (not plugin::StorageEngine::doesTableExist(*session, identifier))
     {
       my_error(ER_TABLE_UNKNOWN, identifier);

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2011-11-09 20:20:23 +0000
+++ drizzled/sql_base.cc	2012-07-11 14:06:00 +0000
@@ -106,7 +106,7 @@
     This has to be done to ensure that the table share is removed from
     the table defintion cache as soon as the last instance is removed
   */
-  identifier::Table identifier(table->getShare()->getSchemaName(), table->getShare()->getTableName(), message::Table::INTERNAL);
+  identifier::Table identifier(table->getShare()->getTableIdentifier().getCatalog(), table->getShare()->getSchemaName(), table->getShare()->getTableName(), message::Table::INTERNAL);
   TableShare *share= new TableShare(identifier.getType(), identifier, identifier.getKey().vector(),  static_cast<uint32_t>(table->getShare()->getCacheKeySize()));
 
   table->cursor->close();
@@ -174,7 +174,7 @@
       bool found= false;
       for (TableList *table= tables; table; table= table->next_local)
       {
-        if (table::Cache::removeTable(*session, identifier::Table(table->getSchemaName(), table->getTableName()), RTFC_OWNED_BY_Session_FLAG))
+        if (table::Cache::removeTable(*session, identifier::Table(catalog().identifier(), table->getSchemaName(), table->getTableName()), RTFC_OWNED_BY_Session_FLAG))
         {
           found= true;
         }
@@ -473,7 +473,8 @@
   {
     if (schema_identifier.compare(table->getShare()->getSchemaName()))
     {
-      set_of_identifiers.push_back(identifier::Table(table->getShare()->getSchemaName(),
+      set_of_identifiers.push_back(identifier::Table(table->getShare()->getTableIdentifier().getCatalog(),
+                                                     table->getShare()->getSchemaName(),
                                                    table->getShare()->getTableName(),
                                                    table->getShare()->getPath()));
     }
@@ -725,7 +726,10 @@
   /*
     Create a table entry with the right key and with an old refresh version
   */
-  identifier::Table identifier(arg.getSchemaName(), arg.getTableName(), message::Table::INTERNAL);
+  identifier::Table identifier(catalog().identifier(),
+                               arg.getSchemaName(),
+                               arg.getTableName(),
+                               message::Table::INTERNAL);
   table::Placeholder* table= new table::Placeholder(this, identifier);
   table::Cache::insert(table);
   return *table;
@@ -824,7 +828,9 @@
     return NULL;
   }
 
-  identifier::Table identifier(table_list->getSchemaName(), table_list->getTableName());
+  identifier::Table identifier(catalog().identifier(),
+                               table_list->getSchemaName(),
+                               table_list->getTableName());
   const identifier::Table::Key &key(identifier.getKey());
   table::CacheRange ppp;
 
@@ -1020,7 +1026,10 @@
 
         if (table_list->isCreate())
         {
-          identifier::Table  lock_table_identifier(table_list->getSchemaName(), table_list->getTableName(), message::Table::STANDARD);
+          identifier::Table  lock_table_identifier(catalog().identifier(),
+                                                   table_list->getSchemaName(),
+                                                   table_list->getTableName(),
+                                                   message::Table::STANDARD);
 
           if (not plugin::StorageEngine::doesTableExist(*this, lock_table_identifier))
           {
@@ -1480,7 +1489,9 @@
      * to see if it exists so that an unauthorized user cannot phish for
      * table/schema information via error messages
      */
-    identifier::Table the_table(tables->getSchemaName(), tables->getTableName());
+    identifier::Table the_table(catalog().identifier(),
+                                tables->getSchemaName(),
+                                tables->getTableName());
     if (not plugin::Authorization::isAuthorized(*user(), the_table))
     {
       result= -1;                               // Fatal error

=== modified file 'drizzled/sql_load.cc'
--- drizzled/sql_load.cc	2012-02-12 08:30:54 +0000
+++ drizzled/sql_load.cc	2012-07-11 14:06:00 +0000
@@ -325,7 +325,8 @@
   info.handle_duplicates=handle_duplicates;
   info.escape_char=escaped->length() ? (*escaped)[0] : INT_MAX;
 
-  identifier::Schema identifier(*schema);
+  identifier::Schema identifier(session->catalog().identifier(),
+                                *schema);
   READ_INFO read_info(file, tot_length,
                       ex->cs ? ex->cs : plugin::StorageEngine::getSchemaCollation(identifier),
 		      *field_term, *ex->line_start, *ex->line_term, *enclosed,

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2012-05-31 15:20:57 +0000
+++ drizzled/sql_parse.cc	2012-07-11 14:06:00 +0000
@@ -225,7 +225,7 @@
         my_message(ER_NO_DB_ERROR, ER(ER_NO_DB_ERROR), MYF(0));
         break;
       }
-      if (not schema::change(session, identifier::Schema(packet)))
+      if (not schema::change(session, identifier::Schema(session.catalog().identifier(), packet)))
       {
         session.my_ok();
       }
@@ -906,7 +906,7 @@
   if (not table->is_derived_table() && table->db.data())
   {
     files_charset_info->casedn_str(table->db.str_);
-    if (not schema::check(*session, identifier::Schema(table->db)))
+    if (not schema::check(*session, identifier::Schema(session->catalog().identifier(), table->db)))
     {
       my_error(ER_WRONG_DB_NAME, MYF(0), table->db.data());
       return NULL;

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2012-03-05 06:00:54 +0000
+++ drizzled/sql_table.cc	2012-07-11 14:06:00 +0000
@@ -65,7 +65,7 @@
 static const char *make_unique_key_name(const char *field_name,KeyInfo *start,KeyInfo *end);
 static bool prepare_blob_field(Session *session, CreateField *sql_field);
 
-void set_table_default_charset(HA_CREATE_INFO *create_info, const char *db)
+void set_table_default_charset(const identifier::Catalog &catalog, HA_CREATE_INFO *create_info, const char *db)
 {
   /*
     If the table character set was not given explicitly,
@@ -73,7 +73,7 @@
     apply it to the table.
   */
   if (not create_info->default_table_charset)
-    create_info->default_table_charset= plugin::StorageEngine::getSchemaCollation(identifier::Schema(str_ref(db)));
+    create_info->default_table_charset= plugin::StorageEngine::getSchemaCollation(identifier::Schema(catalog, str_ref(db)));
 }
 
 /*
@@ -125,7 +125,9 @@
 
     for (table= tables; table; table= table->next_local)
     {
-      identifier::Table tmp_identifier(table->getSchemaName(), table->getTableName());
+      identifier::Table tmp_identifier(session->catalog().identifier(),
+                                       table->getSchemaName(),
+                                       table->getTableName());
 
       error= session->open_tables.drop_temporary_table(tmp_identifier);
 
@@ -159,7 +161,10 @@
           break;
         }
       }
-      identifier::Table identifier(table->getSchemaName(), table->getTableName(), table->getInternalTmpTable() ? message::Table::INTERNAL : message::Table::STANDARD);
+      identifier::Table identifier(session->catalog().identifier(),
+                                   table->getSchemaName(),
+                                   table->getTableName(),
+                                   table->getInternalTmpTable() ? message::Table::INTERNAL : message::Table::STANDARD);
 
       message::table::shared_ptr message= plugin::StorageEngine::getTableMessage(*session, identifier, true);
 
@@ -1406,7 +1411,7 @@
   assert(identifier.getTableName() == table_proto.name());
   db_options= create_info->table_options;
 
-  set_table_default_charset(create_info, identifier.getSchemaName().c_str());
+  set_table_default_charset(session->catalog().identifier(),create_info, identifier.getSchemaName().c_str());
 
   /* Build a Table object to pass down to the engine, and the do the actual create. */
   if (not prepare_create_table(session, create_info, table_proto, alter_info,
@@ -1639,7 +1644,7 @@
   session->abortLock(table);	/* end threads waiting on lock */
 
   /* Wait until all there are no other threads that has this table open */
-  identifier::Table identifier(table->getShare()->getSchemaName(), table->getShare()->getTableName());
+  identifier::Table identifier(session->catalog().identifier(),table->getShare()->getSchemaName(), table->getShare()->getTableName());
   table::Cache::removeTable(*session, identifier, RTFC_WAIT_OTHER_THREAD_FLAG);
 }
 
@@ -1711,7 +1716,7 @@
 
   for (table= tables; table; table= table->next_local)
   {
-    identifier::Table table_identifier(table->getSchemaName(), table->getTableName());
+    identifier::Table table_identifier(session->catalog().identifier(), table->getSchemaName(), table->getTableName());
     bool fatal_error=0;
 
     std::string table_name = table_identifier.getSQLPath();
@@ -1785,7 +1790,7 @@
       const char *old_message=session->enter_cond(COND_refresh, table::Cache::mutex(),
                                                   "Waiting to get writelock");
       session->abortLock(table->table);
-      identifier::Table identifier(table->table->getShare()->getSchemaName(), table->table->getShare()->getTableName());
+      identifier::Table identifier(session->catalog().identifier(),table->table->getShare()->getSchemaName(), table->table->getShare()->getTableName());
       table::Cache::removeTable(*session, identifier, RTFC_WAIT_OTHER_THREAD_FLAG | RTFC_CHECK_KILLED_FLAG);
       session->exit_cond(old_message);
       if (session->getKilled())
@@ -1884,7 +1889,9 @@
         else
         {
           boost::unique_lock<boost::mutex> lock(table::Cache::mutex());
-          identifier::Table identifier(table->table->getShare()->getSchemaName(), table->table->getShare()->getTableName());
+          identifier::Table identifier(session->catalog().identifier(),
+                                       table->table->getShare()->getSchemaName(),
+                                       table->table->getShare()->getTableName());
           table::Cache::removeTable(*session, identifier, RTFC_NO_FLAG);
         }
       }

=== modified file 'drizzled/sql_table.h'
--- drizzled/sql_table.h	2011-08-19 08:06:53 +0000
+++ drizzled/sql_table.h	2012-07-11 14:06:00 +0000
@@ -44,6 +44,6 @@
 
 bool is_primary_key(const char* name);
 bool check_engine(Session*, const char*, message::Table*, HA_CREATE_INFO*);
-void set_table_default_charset(HA_CREATE_INFO *create_info, const char *db);
+void set_table_default_charset(const drizzled::identifier::Catalog&, HA_CREATE_INFO *create_info, const char *db);
 } /* namespace drizzled */
 

=== modified file 'drizzled/statement/alter_schema.cc'
--- drizzled/statement/alter_schema.cc	2011-10-18 13:52:19 +0000
+++ drizzled/statement/alter_schema.cc	2012-07-11 14:06:00 +0000
@@ -27,6 +27,8 @@
 #include <drizzled/message.h>
 #include <drizzled/sql_lex.h>
 
+#include <drizzled/catalog/instance.h>
+
 #include <string>
 
 using namespace std;
@@ -38,7 +40,8 @@
   if (not validateSchemaOptions())
     return true;
 
-  identifier::Schema schema_identifier(lex().name);
+  identifier::Schema schema_identifier(session().catalog().identifier(),
+                                       lex().name);
 
   if (not schema::check(session(), schema_identifier))
   {
@@ -46,7 +49,7 @@
     return false;
   }
 
-  identifier::Schema identifier(lex().name);
+  identifier::Schema identifier(session().catalog().identifier(), lex().name);
   message::schema::shared_ptr old_definition= plugin::StorageEngine::getSchemaDefinition(identifier);
   if (not old_definition)
   {

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2012-02-12 08:54:25 +0000
+++ drizzled/statement/alter_table.cc	2012-07-11 14:06:00 +0000
@@ -51,6 +51,7 @@
 #include <drizzled/open_tables_state.h>
 #include <drizzled/table/cache.h>
 #include <drizzled/create_field.h>
+#include <drizzled/catalog/instance.h>
 
 using namespace std;
 
@@ -128,7 +129,9 @@
   /* Chicken/Egg... we need to search for the table, to know if the table exists, so we can build a full identifier from it */
   message::table::shared_ptr original_table_message;
   {
-    identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName());
+    identifier::Table identifier(session().catalog().identifier(),
+                                 first_table->getSchemaName(),
+                                 first_table->getTableName());
     if (not (original_table_message= plugin::StorageEngine::getTableMessage(session(), identifier)))
     {
       my_error(ER_BAD_TABLE_ERROR, identifier);
@@ -163,8 +166,11 @@
   bool res;
   if (original_table_message->type() == message::Table::STANDARD )
   {
-    identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName());
-    identifier::Table new_identifier(select_lex->db ? select_lex->db : first_table->getSchemaName(),
+    identifier::Table identifier(session().catalog().identifier(),
+                                 first_table->getSchemaName(),
+                                 first_table->getTableName());
+    identifier::Table new_identifier(session().catalog().identifier(),
+                                     select_lex->db ? select_lex->db : first_table->getSchemaName(),
                                    lex().name.data() ? lex().name.data() : first_table->getTableName());
 
     res= alter_table(&session(),
@@ -181,12 +187,19 @@
   }
   else
   {
-    identifier::Table catch22(first_table->getSchemaName(), first_table->getTableName());
+    identifier::Table catch22(session().catalog().identifier(),
+                              first_table->getSchemaName(),
+                              first_table->getTableName());
     Table *table= session().open_tables.find_temporary_table(catch22);
     assert(table);
     {
-      identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName(), table->getMutableShare()->getPath());
-      identifier::Table new_identifier(select_lex->db ? select_lex->db : first_table->getSchemaName(),
+      identifier::Table identifier(session().catalog().identifier(),
+                                   first_table->getSchemaName(),
+                                   first_table->getTableName(),
+                                   table->getMutableShare()->getPath());
+
+      identifier::Table new_identifier(session().catalog().identifier(),
+                                       select_lex->db ? select_lex->db : first_table->getSchemaName(),
                                        lex().name.data() ? lex().name.data() : first_table->getTableName(),
                                        table->getMutableShare()->getPath());
 
@@ -1048,7 +1061,7 @@
     return true;
   }
 
-  set_table_default_charset(create_info, new_table_identifier.getSchemaName().c_str());
+  set_table_default_charset(session->catalog().identifier(), create_info, new_table_identifier.getSchemaName().c_str());
 
   snprintf(tmp_name, sizeof(tmp_name), "%s-%lx_%"PRIx64, TMP_FILE_PREFIX, (unsigned long) current_pid, session->thread_id);
 
@@ -1058,10 +1071,11 @@
     case we just use it as is. Neither of these tables require locks in order to  be
     filled.
   */
-  identifier::Table new_table_as_temporary(original_table_identifier.getSchemaName(),
-                                         tmp_name,
-                                         create_proto.type() != message::Table::TEMPORARY ? message::Table::INTERNAL :
-                                         message::Table::TEMPORARY);
+  identifier::Table new_table_as_temporary(session->catalog().identifier(),
+                                           original_table_identifier.getSchemaName(),
+                                           tmp_name,
+                                           create_proto.type() != message::Table::TEMPORARY ? message::Table::INTERNAL :
+                                           message::Table::TEMPORARY);
 
   /*
     Create a table with a temporary name.
@@ -1247,7 +1261,8 @@
         table. This is when the old and new tables are compatible, according to
         compare_table(). Then, we need one additional call to
       */
-      identifier::Table original_table_to_drop(original_table_identifier.getSchemaName(),
+      identifier::Table original_table_to_drop(session->catalog().identifier(),
+                                               original_table_identifier.getSchemaName(),
                                              old_name, create_proto.type() != message::Table::TEMPORARY ? message::Table::INTERNAL :
                                              message::Table::TEMPORARY);
 

=== modified file 'drizzled/statement/change_schema.cc'
--- drizzled/statement/change_schema.cc	2011-10-18 13:52:19 +0000
+++ drizzled/statement/change_schema.cc	2012-07-11 14:06:00 +0000
@@ -24,6 +24,7 @@
 #include <drizzled/statement/change_schema.h>
 #include <drizzled/schema.h>
 #include <drizzled/sql_lex.h>
+#include <drizzled/catalog/instance.h>
 
 #include <string>
 
@@ -33,7 +34,8 @@
 
 bool statement::ChangeSchema::execute()
 {
-  identifier::Schema identifier(str_ref(lex().select_lex.db));
+  identifier::Schema identifier(session().catalog().identifier(),
+                                str_ref(lex().select_lex.db));
   if (not schema::change(session(), identifier))
   {
     session().my_ok();

=== modified file 'drizzled/statement/create_index.cc'
--- drizzled/statement/create_index.cc	2011-04-09 16:11:46 +0000
+++ drizzled/statement/create_index.cc	2012-07-11 14:06:00 +0000
@@ -26,6 +26,7 @@
 #include <drizzled/statement/alter_table.h>
 #include <drizzled/plugin/storage_engine.h>
 #include <drizzled/open_tables_state.h>
+#include <drizzled/catalog/instance.h>
 
 namespace drizzled
 {
@@ -49,7 +50,9 @@
   /* Chicken/Egg... we need to search for the table, to know if the table exists, so we can build a full identifier from it */
   message::table::shared_ptr original_table_message;
   {
-    identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName());
+    identifier::Table identifier(session().catalog().identifier(),
+                                 first_table->getSchemaName(),
+                                 first_table->getTableName());
     if (not (original_table_message= plugin::StorageEngine::getTableMessage(session(), identifier)))
     {
       my_error(ER_BAD_TABLE_ERROR, identifier);
@@ -76,7 +79,9 @@
   bool res;
   if (original_table_message->type() == message::Table::STANDARD )
   {
-    identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName());
+    identifier::Table identifier(session().catalog().identifier(),
+                                 first_table->getSchemaName(),
+                                 first_table->getTableName());
     create_info().default_table_charset= plugin::StorageEngine::getSchemaCollation(identifier);
 
     res= alter_table(&session(), 
@@ -91,11 +96,16 @@
   }
   else
   {
-    identifier::Table catch22(first_table->getSchemaName(), first_table->getTableName());
+    identifier::Table catch22(session().catalog().identifier(),
+                              first_table->getSchemaName(),
+                              first_table->getTableName());
     Table *table= session().open_tables.find_temporary_table(catch22);
     assert(table);
     {
-      identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName(), table->getMutableShare()->getPath());
+      identifier::Table identifier(session().catalog().identifier(),
+                                   first_table->getSchemaName(),
+                                   first_table->getTableName(),
+                                   table->getMutableShare()->getPath());
       create_info().default_table_charset= plugin::StorageEngine::getSchemaCollation(identifier);
 
       res= alter_table(&session(), 

=== modified file 'drizzled/statement/create_schema.cc'
--- drizzled/statement/create_schema.cc	2011-10-14 09:23:40 +0000
+++ drizzled/statement/create_schema.cc	2012-07-11 14:06:00 +0000
@@ -29,6 +29,7 @@
 #include <drizzled/plugin/storage_engine.h>
 #include <drizzled/sql_lex.h>
 #include <drizzled/plugin/authorization.h>
+#include <drizzled/catalog/instance.h>
 
 #include <string>
 
@@ -47,7 +48,8 @@
     return true;
   }
 
-  identifier::Schema schema_identifier(to_string(lex().name));
+  identifier::Schema schema_identifier(session().catalog().identifier(),
+                                       to_string(lex().name));
   if (not check(schema_identifier))
     return false;
 

=== modified file 'drizzled/statement/create_table.cc'
--- drizzled/statement/create_table.cc	2011-10-14 09:23:40 +0000
+++ drizzled/statement/create_table.cc	2012-07-11 14:06:00 +0000
@@ -29,6 +29,7 @@
 #include <drizzled/plugin/storage_engine.h>
 #include <drizzled/select_create.h>
 #include <drizzled/table_ident.h>
+#include <drizzled/catalog/instance.h>
 
 #include <iostream>
 
@@ -116,7 +117,8 @@
 
   drizzled::message::table::init(createTableMessage(), createTableMessage().name(), create_table_list->getSchemaName(), create_info().db_type->getName());
 
-  identifier::Table new_table_identifier(create_table_list->getSchemaName(),
+  identifier::Table new_table_identifier(session().catalog().identifier(),
+                                         create_table_list->getSchemaName(),
                                        create_table_list->getTableName(),
                                        createTableMessage().type());
 
@@ -239,7 +241,8 @@
       {
         res= create_like_table(&session(), 
                                new_table_identifier,
-                               identifier::Table(select_tables->getSchemaName(),
+                               identifier::Table(session().catalog().identifier(),
+                                                 select_tables->getSchemaName(),
                                                  select_tables->getTableName()),
                                createTableMessage(),
                                lex().exists(),

=== modified file 'drizzled/statement/drop_index.cc'
--- drizzled/statement/drop_index.cc	2011-04-09 16:11:46 +0000
+++ drizzled/statement/drop_index.cc	2012-07-11 14:06:00 +0000
@@ -26,6 +26,7 @@
 #include <drizzled/statement/alter_table.h>
 #include <drizzled/plugin/storage_engine.h>
 #include <drizzled/open_tables_state.h>
+#include <drizzled/catalog/instance.h>
 
 namespace drizzled {
 
@@ -37,7 +38,9 @@
   /* Chicken/Egg... we need to search for the table, to know if the table exists, so we can build a full identifier from it */
   message::table::shared_ptr original_table_message;
   {
-    identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName());
+    identifier::Table identifier(session().catalog().identifier(),
+                                 first_table->getSchemaName(),
+                                 first_table->getTableName());
     if (not (original_table_message= plugin::StorageEngine::getTableMessage(session(), identifier)))
     {
       my_error(ER_BAD_TABLE_ERROR, identifier);
@@ -68,7 +71,9 @@
   bool res;
   if (original_table_message->type() == message::Table::STANDARD )
   {
-    identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName());
+    identifier::Table identifier(session().catalog().identifier(),
+                                 first_table->getSchemaName(),
+                                 first_table->getTableName());
 
     create_info.default_table_charset= plugin::StorageEngine::getSchemaCollation(identifier);
 
@@ -84,11 +89,16 @@
   }
   else
   {
-    identifier::Table catch22(first_table->getSchemaName(), first_table->getTableName());
+    identifier::Table catch22(session().catalog().identifier(),
+                              first_table->getSchemaName(),
+                              first_table->getTableName());
     Table *table= session().open_tables.find_temporary_table(catch22);
     assert(table);
     {
-      identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName(), table->getShare()->getPath());
+      identifier::Table identifier(session().catalog().identifier(),
+                                   first_table->getSchemaName(),
+                                   first_table->getTableName(),
+                                   table->getShare()->getPath());
       create_info.default_table_charset= plugin::StorageEngine::getSchemaCollation(identifier);
 
       res= alter_table(&session(), 

=== modified file 'drizzled/statement/drop_schema.cc'
--- drizzled/statement/drop_schema.cc	2011-10-14 09:23:40 +0000
+++ drizzled/statement/drop_schema.cc	2012-07-11 14:06:00 +0000
@@ -26,6 +26,7 @@
 #include <drizzled/plugin/event_observer.h>
 #include <drizzled/sql_lex.h>
 #include <drizzled/schema.h>
+#include <drizzled/catalog/instance.h>
 
 #include <string>
 
@@ -41,7 +42,8 @@
     return true;
   }
 
-  identifier::Schema schema_identifier(to_string(lex().name));
+  identifier::Schema schema_identifier(session().catalog().identifier(),
+                                       to_string(lex().name));
 
   if (not schema::check(session(), schema_identifier))
   {

=== modified file 'drizzled/statement/rename_table.cc'
--- drizzled/statement/rename_table.cc	2011-06-23 10:47:03 +0000
+++ drizzled/statement/rename_table.cc	2012-07-11 14:06:00 +0000
@@ -28,6 +28,7 @@
 #include <drizzled/transaction_services.h>
 #include <drizzled/sql_lex.h>
 #include <drizzled/table/cache.h>
+#include <drizzled/catalog/instance.h>
 
 namespace drizzled {
 
@@ -156,7 +157,10 @@
   plugin::StorageEngine *engine= NULL;
   message::table::shared_ptr table_message;
 
-  identifier::Table old_identifier(ren_table->getSchemaName(), old_alias, message::Table::STANDARD);
+  identifier::Table old_identifier(session().catalog().identifier(),
+                                   ren_table->getSchemaName(),
+                                   old_alias,
+                                   message::Table::STANDARD);
 
   if (not (table_message= plugin::StorageEngine::getTableMessage(session(), old_identifier)))
   {
@@ -166,7 +170,8 @@
 
   engine= plugin::StorageEngine::findByName(session(), table_message->engine().name());
 
-  identifier::Table new_identifier(new_db, new_alias, message::Table::STANDARD);
+  identifier::Table new_identifier(session().catalog().identifier(),
+                                   new_db, new_alias, message::Table::STANDARD);
   if (plugin::StorageEngine::doesTableExist(session(), new_identifier))
   {
     my_error(ER_TABLE_EXISTS_ERROR, new_identifier);

=== modified file 'drizzled/table/concurrent.cc'
--- drizzled/table/concurrent.cc	2011-06-29 12:57:43 +0000
+++ drizzled/table/concurrent.cc	2012-07-11 14:06:00 +0000
@@ -31,6 +31,7 @@
 #include <drizzled/table/instance.h>
 #include <drizzled/table.h>
 #include <drizzled/table_list.h>
+#include <drizzled/catalog/instance.h>
 
 namespace drizzled {
 namespace table {
@@ -65,7 +66,10 @@
   if (session->getKilled())
     return true;
 
-  identifier::Table identifier(table_list->getSchemaName(), table_list->getTableName());
+  identifier::Table identifier(session->catalog().identifier(),
+                               table_list->getSchemaName(),
+                               table_list->getTableName());
+
   if (open_unireg_entry(session, table_list->getTableName(), identifier))
   {
     intern_close_table();

=== modified file 'drizzled/table/instance/base.cc'
--- drizzled/table/instance/base.cc	2012-07-11 13:10:06 +0000
+++ drizzled/table/instance/base.cc	2012-07-11 14:06:00 +0000
@@ -86,6 +86,7 @@
 #include <drizzled/typelib.h>
 #include <drizzled/key.h>
 #include <drizzled/open_tables_state.h>
+#include <drizzled/catalog/local.h>
 
 using namespace std;
 
@@ -487,7 +488,9 @@
   table_category= TABLE_CATEGORY_TEMPORARY;
   tmp_table= message::Table::INTERNAL;
 
-  identifier::Table *n= new identifier::Table("", new_table_name, new_path);
+  /* local_identifier() is okay to use here as the path is what matters */
+  identifier::Table *n= new identifier::Table(catalog::local_identifier(),
+                                              "", new_table_name, new_path);
   delete table_identifier;
   table_identifier= n;
 

=== modified file 'drizzled/table/instance/base.h'
--- drizzled/table/instance/base.h	2012-07-11 12:59:54 +0000
+++ drizzled/table/instance/base.h	2012-07-11 14:06:00 +0000
@@ -278,6 +278,11 @@
     return table_identifier->getSchemaName().c_str();
   }
 
+  const drizzled::identifier::Table &getTableIdentifier() const
+  {
+    return *table_identifier;
+  }
+
   uint32_t   block_size;                   /* create information */
 
 private:

=== modified file 'drizzled/table/singular.cc'
--- drizzled/table/singular.cc	2011-08-08 12:51:19 +0000
+++ drizzled/table/singular.cc	2012-07-11 14:06:00 +0000
@@ -126,8 +126,7 @@
 
 bool Singular::open_tmp_table()
 {
-  identifier::Table identifier(getShare()->getSchemaName(), getShare()->getTableName(), getShare()->getPath());
-  if (int error= cursor->ha_open(identifier, O_RDWR, HA_OPEN_TMP_TABLE | HA_OPEN_INTERNAL_TABLE))
+  if (int error= cursor->ha_open(getShare()->getTableIdentifier(), O_RDWR, HA_OPEN_TMP_TABLE | HA_OPEN_INTERNAL_TABLE))
   {
     print_error(error, MYF(0));
     db_stat= 0;
@@ -301,9 +300,8 @@
     if (db_stat)
       cursor->closeMarkForDelete();
 
-    identifier::Table identifier(getShare()->getSchemaName(), getShare()->getTableName(), getShare()->getTableName());
     drizzled::error_t ignored;
-    plugin::StorageEngine::dropTable(*in_use, *getShare()->getEngine(), identifier, ignored);
+    plugin::StorageEngine::dropTable(*in_use, *getShare()->getEngine(), getShare()->getTableIdentifier(), ignored);
     delete cursor;
   }
 

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2012-05-25 23:45:18 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2012-07-11 14:06:00 +0000
@@ -610,7 +610,10 @@
 
   if (search_string.compare("data_dictionary") == 0)
   {
-    set_of_identifiers.push_back(identifier::Table(schema_identifier.getSchemaName(), "SYS_REPLICATION_LOG"));
+    set_of_identifiers.push_back(identifier::Table(
+                                            catalog::local_identifier(),
+                                            schema_identifier.getSchemaName(),
+                                            "SYS_REPLICATION_LOG"));
   }
 
   for (CachedDirectory::Entries::iterator entry_iter= entries.begin(); 
@@ -640,7 +643,7 @@
            Using schema_identifier here to stop unused warning, could use
            definition.schema() instead
         */
-        identifier::Table identifier(schema_identifier.getSchemaName(), definition.name());
+        identifier::Table identifier(schema_identifier, definition.name());
         set_of_identifiers.push_back(identifier);
       }
     }

=== modified file 'plugin/memory/ha_heap.cc'
--- plugin/memory/ha_heap.cc	2012-01-15 20:54:59 +0000
+++ plugin/memory/ha_heap.cc	2012-07-11 14:06:00 +0000
@@ -250,9 +250,7 @@
 Cursor *ha_heap::clone(memory::Root *)
 {
   Cursor *new_handler= getTable()->getMutableShare()->db_type()->getCursor(*getTable());
-  identifier::Table identifier(getTable()->getShare()->getSchemaName(),
-                             getTable()->getShare()->getTableName(),
-                             getTable()->getShare()->getPath());
+  identifier::Table identifier(*getTable());
 
   if (new_handler && !new_handler->ha_open(identifier, getTable()->db_stat,
                                            HA_OPEN_IGNORE_IF_LOCKED))

=== modified file 'plugin/schema_engine/schema.cc'
--- plugin/schema_engine/schema.cc	2012-01-16 02:37:54 +0000
+++ plugin/schema_engine/schema.cc	2012-07-11 14:06:00 +0000
@@ -26,7 +26,8 @@
 #include <drizzled/sql_table.h>
 #include <drizzled/charset.h>
 #include <drizzled/cursor.h>
-#include <drizzled/catalog/local.h>
+#include <drizzled/data_home.h>
+#include <drizzled/message/catalog.h>
 
 #include <drizzled/pthread_globals.h>
 
@@ -69,9 +70,9 @@
   table_definition_ext= DEFAULT_FILE_EXTENSION;
 }
 
-void Schema::prime()
+void Schema::prime_catalog(identifier::Catalog &catalog_identifier)
 {
-  CachedDirectory directory(catalog::local_identifier().getPath(),
+  CachedDirectory directory(catalog_identifier.getPath(),
                             CachedDirectory::DIRECTORY, true);
 
   CachedDirectory::Entries files= directory.getEntries();
@@ -83,13 +84,20 @@
       continue;
     message::Schema schema_message;
 
-    std::string filename= catalog::local_identifier().getPath();
+    std::string filename= catalog_identifier.getPath();
     filename+= FN_LIBCHAR;
     filename+= entry->filename;
 
     if (readSchemaFile(filename, schema_message))
     {
-      identifier::Schema schema_identifier(schema_message.name());
+
+      identifier::Schema schema_identifier(catalog_identifier,
+                                           schema_message.name());
+
+      if (! schema_message.has_catalog())
+      {
+        schema_message.set_catalog(catalog_identifier.name());
+      }
 
       pair<SchemaCache::iterator, bool> ret=
         schema_cache.insert(make_pair(schema_identifier.getPath(), new message::Schema(schema_message)));
@@ -99,11 +107,34 @@
   }
 }
 
+void Schema::prime()
+{
+  drizzled::CachedDirectory directory(drizzled::getDataHome().file_string(),
+                                      drizzled::CachedDirectory::DIRECTORY,
+                                      true);
+  drizzled::CachedDirectory::Entries files= directory.getEntries();
+
+  for (drizzled::CachedDirectory::Entries::iterator fileIter= files.begin();
+       fileIter != files.end(); fileIter++)
+  {
+    drizzled::CachedDirectory::Entry *entry= *fileIter;
+    drizzled::message::catalog::shared_ptr message;
+
+    if (not entry->filename.compare(GLOBAL_TEMPORARY_EXT))
+      continue;
+
+    drizzled::identifier::Catalog identifier(entry->filename);
+
+    prime_catalog(identifier);
+  }
+}
+
 void Schema::doGetSchemaIdentifiers(identifier::schema::vector &set_of_names)
 {
   mutex.lock_shared();
   BOOST_FOREACH(SchemaCache::reference iter, schema_cache)
-    set_of_names.push_back(identifier::Schema(iter.second->name()));
+    set_of_names.push_back(identifier::Schema(identifier::Catalog(iter.second->catalog()),
+                                              iter.second->name()));
   mutex.unlock_shared();
 }
 
@@ -124,7 +155,8 @@
 
 bool Schema::doCreateSchema(const drizzled::message::Schema &schema_message)
 {
-  identifier::Schema schema_identifier(schema_message.name());
+  identifier::Schema schema_identifier(identifier::Catalog(schema_message.catalog()),
+                                       schema_message.name());
 
   if (mkdir(schema_identifier.getPath().c_str(), 0777) == -1)
   {
@@ -186,7 +218,8 @@
 
 bool Schema::doAlterSchema(const drizzled::message::Schema &schema_message)
 {
-  identifier::Schema schema_identifier(schema_message.name());
+  identifier::Schema schema_identifier(identifier::Catalog(schema_message.catalog()),
+                                       schema_message.name());
 
   if (access(schema_identifier.getPath().c_str(), F_OK))
     return false;

=== modified file 'plugin/schema_engine/schema.h'
--- plugin/schema_engine/schema.h	2011-06-21 20:40:13 +0000
+++ plugin/schema_engine/schema.h	2012-07-11 14:06:00 +0000
@@ -33,6 +33,7 @@
   bool readSchemaFile(const drizzled::identifier::Schema &schema_identifier, drizzled::message::Schema &schema);
   bool readSchemaFile(std::string filename, drizzled::message::Schema &schema);
 
+  void prime_catalog(drizzled::identifier::Catalog &catalog_identifier);
   void prime();
 
   typedef boost::unordered_map<std::string, drizzled::message::schema::shared_ptr> SchemaCache;

=== modified file 'plugin/show_dictionary/show_columns.cc'
--- plugin/show_dictionary/show_columns.cc	2011-07-13 05:35:09 +0000
+++ plugin/show_dictionary/show_columns.cc	2012-07-11 14:06:00 +0000
@@ -51,7 +51,9 @@
   if (not select.getShowTable().empty() && not select.getShowSchema().empty())
   {
     table_name.append(select.getShowTable().c_str());
-    identifier::Table identifier(select.getShowSchema().c_str(), select.getShowTable().c_str());
+    identifier::Table identifier(getSession().catalog().identifier(),
+                                 select.getShowSchema().c_str(),
+                                 select.getShowTable().c_str());
 
     if (not plugin::Authorization::isAuthorized(*getSession().user(),
                                             identifier, false))

=== modified file 'plugin/show_dictionary/show_create_schema.cc'
--- plugin/show_dictionary/show_create_schema.cc	2011-03-10 11:57:20 +0000
+++ plugin/show_dictionary/show_create_schema.cc	2012-07-11 14:06:00 +0000
@@ -47,7 +47,8 @@
   if (not select.getShowSchema().empty())
   {
     schema_name.append(select.getShowTable());
-    identifier::Schema identifier(select.getShowSchema());
+    identifier::Schema identifier(getSession().catalog().identifier(),
+                                  select.getShowSchema());
 
     if (not plugin::Authorization::isAuthorized(*getSession().user(),
                                                 identifier, false))

=== modified file 'plugin/show_dictionary/show_create_table.cc'
--- plugin/show_dictionary/show_create_table.cc	2011-03-18 16:53:27 +0000
+++ plugin/show_dictionary/show_create_table.cc	2012-07-11 14:06:00 +0000
@@ -48,7 +48,9 @@
 
   if (not select.getShowTable().empty() && not select.getShowSchema().empty())
   {
-    identifier::Table identifier(select.getShowSchema(), select.getShowTable());
+    identifier::Table identifier(getSession().catalog().identifier(),
+                                 select.getShowSchema(),
+                                 select.getShowTable());
 
     if (not plugin::Authorization::isAuthorized(*getSession().user(),
                                             identifier, false))

=== modified file 'plugin/show_dictionary/show_indexes.cc'
--- plugin/show_dictionary/show_indexes.cc	2011-03-10 11:57:20 +0000
+++ plugin/show_dictionary/show_indexes.cc	2012-07-11 14:06:00 +0000
@@ -52,7 +52,9 @@
   if (not select.getShowTable().empty() && not select.getShowSchema().empty())
   {
     table_name.append(select.getShowTable().c_str());
-    identifier::Table identifier(select.getShowSchema().c_str(), select.getShowTable().c_str());
+    identifier::Table identifier(getSession().catalog().identifier(),
+                                 select.getShowSchema().c_str(),
+                                 select.getShowTable().c_str());
 
     if (not plugin::Authorization::isAuthorized(*getSession().user(),
                                             identifier, false))

=== modified file 'plugin/show_dictionary/show_tables.cc'
--- plugin/show_dictionary/show_tables.cc	2011-06-17 13:43:52 +0000
+++ plugin/show_dictionary/show_tables.cc	2012-07-11 14:06:00 +0000
@@ -62,7 +62,8 @@
       return false;
     }
 
-    identifier::Schema identifier(schema_name);
+    identifier::Schema identifier(getSession().catalog().identifier(),
+                                  schema_name);
     plugin::StorageEngine::getIdentifiers(getSession(), identifier, set_of_identifiers);
     table_iterator= set_of_identifiers.begin();
     is_primed= true;

=== modified file 'plugin/show_schema_proto/show_schema_proto.cc'
--- plugin/show_schema_proto/show_schema_proto.cc	2012-01-15 20:54:59 +0000
+++ plugin/show_schema_proto/show_schema_proto.cc	2012-07-11 14:06:00 +0000
@@ -25,6 +25,10 @@
 #include <drizzled/plugin/function.h>
 #include <drizzled/plugin/storage_engine.h>
 
+#include <drizzled/identifier.h>
+#include <drizzled/session.h>
+#include <drizzled/catalog/instance.h>
+
 #include <iostream>
 #include <stdio.h>
 #include <string>
@@ -74,7 +78,8 @@
 
   null_value= false;
 
-  identifier::Schema schema_identifier(*db_sptr);
+  identifier::Schema schema_identifier(getSession().catalog().identifier(),
+                                       *db_sptr);
   message::schema::shared_ptr proto= plugin::StorageEngine::getSchemaDefinition(schema_identifier);
   if (not proto)
   {

=== modified file 'unittests/table_identifier.cc'
--- unittests/table_identifier.cc	2012-07-11 12:59:54 +0000
+++ unittests/table_identifier.cc	2012-07-11 14:06:00 +0000
@@ -30,21 +30,21 @@
 BOOST_AUTO_TEST_SUITE(TableIdentifierTest)
 BOOST_AUTO_TEST_CASE(CreateStandard)
 {
-  identifier::Table identifier("test", "a");
+  identifier::Table identifier(identifier::Catalog(str_ref("local")), "test", "a");
   BOOST_REQUIRE_EQUAL("local/test/a", identifier.getPath());
   BOOST_REQUIRE_EQUAL("test.a", identifier.getSQLPath());
 }
 
 BOOST_AUTO_TEST_CASE(CreateTemporary)
 {
-  identifier::Table identifier("test", "a", message::Table::TEMPORARY);
+  identifier::Table identifier(identifier::Catalog(str_ref("local")),"test", "a", message::Table::TEMPORARY);
   BOOST_REQUIRE_EQUAL("/#sql", identifier.getPath().substr(0, 5));
   BOOST_REQUIRE_EQUAL("test.#a", identifier.getSQLPath());
 }
 
 BOOST_AUTO_TEST_CASE(CreateInternal)
 {
-  identifier::Table identifier("test", "a", message::Table::TEMPORARY);
+  identifier::Table identifier(identifier::Catalog(str_ref("local")),"test", "a", message::Table::TEMPORARY);
   BOOST_REQUIRE_EQUAL("/#sql", identifier.getPath().substr(0, 5));
   BOOST_REQUIRE_EQUAL("test.#a", identifier.getSQLPath());
 }
@@ -59,7 +59,7 @@
 
 BOOST_AUTO_TEST_CASE(Key)
 {
-  identifier::Table identifier("test", "a");
+  identifier::Table identifier(identifier::Catalog(str_ref("LOCAL")),"test", "a");
 
   const identifier::Table::Key key= identifier.getKey();
 
@@ -82,8 +82,8 @@
 
 BOOST_AUTO_TEST_CASE(KeyCompare)
 {
-  identifier::Table identifier("test", "a");
-  identifier::Table identifier2("test", "a");
+  identifier::Table identifier(identifier::Catalog(str_ref("local")), "test", "a");
+  identifier::Table identifier2(identifier::Catalog(str_ref("local")), "test", "a");
 
   BOOST_REQUIRE_EQUAL((identifier.getKey() == identifier.getKey()), true);
 }

